pub struct Flags(/* private fields */);Expand description
Flags field.
Definitions from Wikipedia.
Implementations
Sourceimpl Flags
impl Flags
Sourcepub const LEFT_ALIGN: Self
pub const LEFT_ALIGN: Self
Left-align the output of this placeholder. (The default is to right-align the output.)
Sourcepub const PREPEND_PLUS: Self
pub const PREPEND_PLUS: Self
Prepends a plus for positive signed-numeric types. positive =
+, negative = -.
(The default doesn’t prepend anything in front of positive numbers.)
Sourcepub const PREPEND_SPACE: Self
pub const PREPEND_SPACE: Self
Prepends a space for positive signed-numeric types. positive = , negative = -. This flag is ignored if the
PREPEND_PLUS flag exists.
(The default doesn’t prepend anything in front of positive numbers.)
Sourcepub const PREPEND_ZERO: Self
pub const PREPEND_ZERO: Self
When the ‘width’ option is specified, prepends zeros for numeric types. (The default prepends spaces.)
For example, printf("%4X",3) produces 3, while
printf("%04X",3) produces 0003.
Sourcepub const THOUSANDS_GROUPING: Self
pub const THOUSANDS_GROUPING: Self
The integer or exponent of a decimal has the thousands grouping separator applied.
Sourcepub const ALTERNATE_FORM: Self
pub const ALTERNATE_FORM: Self
Alternate form:
For g and G types, trailing zeros are not removed.
For f, F, e, E, g, G types, the output always
contains a decimal point. \ For o, x, X types,
the text 0, 0x, 0X, respectively, is prepended
to non-zero numbers.
Sourceimpl Flags
impl Flags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Flags
impl Flags
Sourcepub const fn iter(&self) -> Iter<Flags>
pub const fn iter(&self) -> Iter<Flags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Flags>
pub const fn iter_names(&self) -> IterNames<Flags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.