pub unsafe fn format(
format: *const c_char,
args: &mut VaListTag,
handler: impl FnMut(Argument<'_>) -> c_int,
) -> c_intExpand description
Parse a format parameter and write it somewhere.
Safety
The args walk is as unsafe as any va_list: the arguments the
caller passed must match the passed format, which must be a valid
printf format string.